@@ -6,13 +6,14 @@ import numpy as np
 TEST_DATA_DIR = Path(__file__).parent.parent / 'test'
 
 run_aretomo_alignment(
-    tilt_series_file=TEST_DATA_DIR / 'TS_121.st',
     tilt_angles=np.arange(-42,51,3),
+    tilt_series_file=TEST_DATA_DIR / 'TS_121.st',
     pixel_size=1.329,
     output_directory=TEST_DATA_DIR / 'output',
-    exe='/s/ems/s/AreTomo/v1.1.0/AreTomo_1.1.0_Cuda114_03-24-2022',
+    aretomo_executable='/s/ems/s/AreTomo/v1.1.0/AreTomo_1.1.0_Cuda114_03-24-2022',
     local_align=True,
-    patch_in_x=6,
-    patch_in_y=4,
+    n_patches_x=6,
+    n_patches_y=4,
+    thickness_for_alignment=600,
     correct_tilt_angle_offset=True
 )
